@@ -602,7 +602,10 @@ class URLShorten(dbus.service.Object):
             shortener = dbus.Interface(obj, "com.Gwibber.URLShorten")
             short_url = shortener.Shorten(url)
     """
-    service = SETTINGS["urlshorter"] or "is.gd"
+    if SETTINGS["urlshorter"] in urlshorter.PROTOCOLS.keys():
+      service = SETTINGS["urlshorter"]
+    else:
+      service = "is.gd"
     log.logger.info("Shortening URL %s with %s", url, service)
     if self.IsShort(url): return url
     try:
