@@ -2,6 +2,10 @@
 import os, locale, re, mx.DateTime, cgi
 import log
 import resources
+from couch import RecordMonitor
+import dbus
+from const import * 
+
 
 COUNT = 200
 
@@ -92,3 +96,33 @@ except:
   can_notify = False
 
 
+def getbus(path, address="com.Gwibber"):
+  if not path.startswith("/"):
+    path = "/com/gwibber/%s" % path
+    if len(path.split('gwibber/')[1]) > 1:
+      address = "com.Gwibber.%s" % path.split('wibber/')[1]
+  bus = dbus.SessionBus()
+  obj = bus.get_object(address, path,
+      follow_name_owner_changes = True)
+  return dbus.Interface(obj, address)
+
+def service_is_running(name):
+  return name in dbus.Interface(dbus.SessionBus().get_object(
+    "org.freedesktop.DBus", "/org/freedesktop/DBus"),
+      "org.freedesktop.DBus").ListNames()
+
+class SettingsMonitor(RecordMonitor):
+  def __init__(self):
+    RecordMonitor.__init__(self,
+        COUCH_DB_SETTINGS,
+        COUCH_RECORD_SETTINGS,
+        COUCH_TYPE_CONFIG,
+        DEFAULT_SETTINGS)
+
+  def setup_monitor(self):
+    if service_is_running("com.Gwibber.Streams"):
+      getbus("Streams").connect_to_signal("SettingChanged", self.refresh)
+    else:
+      print "No dbus monitor yet"
+      RecordMonitor.setup_monitor(self)
+
