@@ -14,6 +14,8 @@ if environ.has_key("FB_APP_KEY"):
 else:
   FB_APP_KEY = "71b85c6d8cb5bbb9f1a3f8bbdcdd4b05"
 
+TWITTER_OAUTH_KEY = "VDOuA5qCJ1XhjaSa4pl76g"
+TWITTER_OAUTH_SECRET = "BqHlB8sMz5FhZmmFimwgiIdB0RiBr72Y0bio49IVJM"
 
 # Gwibber
 MAX_MESSAGE_LENGTH = 140
@@ -51,7 +53,7 @@ RETWEET_FORMATS = {
   "service": "{R} @{nick}: {text}",
 }
 
-VERSION_NUMBER = "2.30.1"
+VERSION_NUMBER = "2.30.2"
 GCONF_CLIENT_DIR = "/apps/gwibber/client/"
 
 BUG_URL = "https://bugs.launchpad.net/gwibber/+filebug"
